@@ -258,7 +258,7 @@ namespace pika {
                     }
 
                     // call supplied callback with or without index
-                    if constexpr (pika::detail::is_invocable_v<F, std::size_t,
+                    if constexpr (std::is_invocable_v<F, std::size_t,
                                       future_type>)
                     {
                         f_(count_, PIKA_MOVE(*next));
@@ -314,8 +314,7 @@ namespace pika {
                 }
 
                 // call supplied callback with or without index
-                if constexpr (pika::detail::is_invocable_v<F, std::size_t,
-                                  future_type>)
+                if constexpr (std::is_invocable_v<F, std::size_t, future_type>)
                 {
                     f_(count_, PIKA_MOVE(fut));
                 }
