@@ -14,13 +14,13 @@
 #include <pika/async_mpi/mpi_polling.hpp>
 #include <pika/concepts/concepts.hpp>
 #include <pika/datastructures/variant.hpp>
+#include <pika/execution/algorithms/detail/helpers.hpp>
 #include <pika/execution/algorithms/detail/partial_algorithm.hpp>
 #include <pika/execution_base/receiver.hpp>
 #include <pika/execution_base/sender.hpp>
 #include <pika/functional/detail/tag_fallback_invoke.hpp>
 #include <pika/functional/invoke.hpp>
 #include <pika/functional/invoke_fused.hpp>
-#include <pika/functional/traits/is_invocable.hpp>
 #include <pika/mpi_base/mpi.hpp>
 
 #include <exception>
@@ -79,7 +79,7 @@ namespace pika::mpi::experimental {
 
         template <typename F, typename... Ts>
         inline constexpr bool is_mpi_request_invocable_v =
-            pika::detail::is_invocable_v<F,
+            std::is_invocable_v<F,
                 std::add_lvalue_reference_t<std::decay_t<Ts>>..., MPI_Request*>;
 
         template <typename F, typename... Ts>
@@ -106,24 +106,13 @@ namespace pika::mpi::experimental {
             stream_type stream;
 
 #if defined(PIKA_HAVE_P2300_REFERENCE_IMPLEMENTATION)
-            template <typename T>
-            struct result_type_signature_helper
-            {
-                using type = pika::execution::experimental::set_value_t(T);
-            };
-
-            template <>
-            struct result_type_signature_helper<void>
-            {
-                using type = pika::execution::experimental::set_value_t();
-            };
-
             template <typename... Ts>
             requires is_mpi_request_invocable_v<F, Ts...>
             using invoke_result_helper =
                 pika::execution::experimental::completion_signatures<
-                    typename result_type_signature_helper<
-                        mpi_request_invoke_result_t<F, Ts...>>::type>;
+                    pika::execution::experimental::detail::
+                        result_type_signature_helper_t<
+                            mpi_request_invoke_result_t<F, Ts...>>>;
 
             using completion_signatures =
                 pika::execution::experimental::make_completion_signatures<
