@@ -17,8 +17,8 @@
 #include <pika/assert.hpp>
 #include <pika/concepts/concepts.hpp>
 #include <pika/datastructures/variant.hpp>
+#include <pika/execution/algorithms/detail/helpers.hpp>
 #include <pika/execution/algorithms/detail/partial_algorithm.hpp>
-#include <pika/execution/algorithms/detail/single_result.hpp>
 #include <pika/execution_base/operation_state.hpp>
 #include <pika/execution_base/receiver.hpp>
 #include <pika/execution_base/sender.hpp>
@@ -438,12 +438,12 @@ namespace pika::ensure_started_detail {
             state->start();
         }
 
-        ensure_started_sender_type(ensure_started_sender_type const&) = default;
-        ensure_started_sender_type& operator=(
-            ensure_started_sender_type const&) = default;
         ensure_started_sender_type(ensure_started_sender_type&&) = default;
         ensure_started_sender_type& operator=(
             ensure_started_sender_type&&) = default;
+        ensure_started_sender_type(ensure_started_sender_type const&) = delete;
+        ensure_started_sender_type& operator=(
+            ensure_started_sender_type const&) = delete;
 
         template <typename Receiver>
         struct operation_state
