@@ -14,7 +14,7 @@
 #include <pika/concepts/concepts.hpp>
 #include <pika/datastructures/member_pack.hpp>
 #include <pika/datastructures/variant.hpp>
-#include <pika/execution/algorithms/detail/single_result.hpp>
+#include <pika/execution/algorithms/detail/helpers.hpp>
 #include <pika/execution_base/operation_state.hpp>
 #include <pika/execution_base/receiver.hpp>
 #include <pika/execution_base/sender.hpp>
@@ -348,7 +348,7 @@ namespace pika::when_all_impl {
 
             using operation_state_type =
                 std::decay_t<decltype(pika::execution::experimental::connect(
-                    PIKA_FORWARD(SendersPack, senders).template get<i>(),
+                    std::declval<SendersPack>().template get<i>(),
                     when_all_receiver<operation_state>(
                         std::declval<std::decay_t<operation_state>&>())))>;
             operation_state_type op_state;
@@ -401,7 +401,8 @@ namespace pika::when_all_impl {
             when_all_sender_type& s, Receiver&& receiver)
         {
             return operation_state<Receiver, senders_type&,
-                num_predecessors - 1>(receiver, s.senders);
+                num_predecessors - 1>(
+                PIKA_FORWARD(Receiver, receiver), s.senders);
         }
     };
 }    // namespace pika::when_all_impl
