@@ -134,8 +134,8 @@ namespace pika::execution::experimental {
             return *this;
         }
 
-        template <typename Enable = std::enable_if_t<
-                      pika::detail::is_invocable_v<with_priority_t,
+        template <typename Enable =
+                      std::enable_if_t<std::is_invocable_v<with_priority_t,
                           BaseScheduler, pika::execution::thread_priority>>>
         friend scheduler_executor
         tag_invoke(pika::execution::experimental::with_priority_t,
@@ -145,9 +145,8 @@ namespace pika::execution::experimental {
             return scheduler_executor(with_priority(exec.sched_, priority));
         }
 
-        template <
-            typename Enable = std::enable_if_t<
-                pika::detail::is_invocable_v<get_priority_t, BaseScheduler>>>
+        template <typename Enable = std::enable_if_t<
+                      std::is_invocable_v<get_priority_t, BaseScheduler>>>
         friend pika::execution::thread_priority
         tag_invoke(pika::execution::experimental::get_priority_t,
             scheduler_executor const& exec)
@@ -155,8 +154,8 @@ namespace pika::execution::experimental {
             return get_priority(exec.sched_);
         }
 
-        template <typename Enable = std::enable_if_t<
-                      pika::detail::is_invocable_v<with_stacksize_t,
+        template <typename Enable =
+                      std::enable_if_t<std::is_invocable_v<with_stacksize_t,
                           BaseScheduler, pika::execution::thread_stacksize>>>
         friend scheduler_executor
         tag_invoke(pika::execution::experimental::with_stacksize_t,
@@ -166,9 +165,8 @@ namespace pika::execution::experimental {
             return scheduler_executor(with_stacksize(exec.sched_, stacksize));
         }
 
-        template <
-            typename Enable = std::enable_if_t<
-                pika::detail::is_invocable_v<get_stacksize_t, BaseScheduler>>>
+        template <typename Enable = std::enable_if_t<
+                      std::is_invocable_v<get_stacksize_t, BaseScheduler>>>
         friend pika::execution::thread_stacksize
         tag_invoke(pika::execution::experimental::get_stacksize_t,
             scheduler_executor const& exec)
@@ -176,9 +174,9 @@ namespace pika::execution::experimental {
             return get_stacksize(exec.sched_);
         }
 
-        template <typename Enable = std::enable_if_t<
-                      pika::detail::is_invocable_v<with_hint_t, BaseScheduler,
-                          pika::execution::thread_schedule_hint>>>
+        template <
+            typename Enable = std::enable_if_t<std::is_invocable_v<with_hint_t,
+                BaseScheduler, pika::execution::thread_schedule_hint>>>
         friend scheduler_executor
         tag_invoke(pika::execution::experimental::with_hint_t,
             scheduler_executor const& exec,
@@ -188,7 +186,7 @@ namespace pika::execution::experimental {
         }
 
         template <typename Enable = std::enable_if_t<
-                      pika::detail::is_invocable_v<get_hint_t, BaseScheduler>>>
+                      std::is_invocable_v<get_hint_t, BaseScheduler>>>
         friend pika::execution::thread_schedule_hint
         tag_invoke(pika::execution::experimental::get_hint_t,
             scheduler_executor const& exec)
@@ -196,9 +194,8 @@ namespace pika::execution::experimental {
             return get_hint(exec.sched_);
         }
 
-        template <
-            typename Enable = std::enable_if_t<pika::detail::is_invocable_v<
-                with_annotation_t, BaseScheduler, char const*>>>
+        template <typename Enable = std::enable_if_t<std::is_invocable_v<
+                      with_annotation_t, BaseScheduler, char const*>>>
         friend scheduler_executor
         tag_invoke(pika::execution::experimental::with_annotation_t,
             scheduler_executor const& exec, char const* annotation)
@@ -206,9 +203,8 @@ namespace pika::execution::experimental {
             return scheduler_executor(with_annotation(exec.sched_, annotation));
         }
 
-        template <
-            typename Enable = std::enable_if_t<pika::detail::is_invocable_v<
-                with_annotation_t, BaseScheduler, std::string>>>
+        template <typename Enable = std::enable_if_t<std::is_invocable_v<
+                      with_annotation_t, BaseScheduler, std::string>>>
         friend scheduler_executor
         tag_invoke(pika::execution::experimental::with_annotation_t,
             scheduler_executor const& exec, std::string annotation)
@@ -216,9 +212,8 @@ namespace pika::execution::experimental {
             return scheduler_executor(with_annotation(exec.sched_, annotation));
         }
 
-        template <
-            typename Enable = std::enable_if_t<
-                pika::detail::is_invocable_v<get_annotation_t, BaseScheduler>>>
+        template <typename Enable = std::enable_if_t<
+                      std::is_invocable_v<get_annotation_t, BaseScheduler>>>
         friend char const*
         tag_invoke(pika::execution::experimental::get_annotation_t,
             scheduler_executor const& exec)
