@@ -13,7 +13,7 @@
 #include <iterator>
 #include <type_traits>
 
-namespace pika { namespace lcos { namespace detail {
+namespace pika::lcos::detail {
     ///////////////////////////////////////////////////////////////////////////
     template <typename Iter, typename Enable = void>
     struct future_iterator_traits
@@ -31,4 +31,4 @@ namespace pika { namespace lcos { namespace detail {
     template <typename Iter>
     using future_iterator_traits_t =
         typename future_iterator_traits<Iter>::type;
-}}}    // namespace pika::lcos::detail
+}    // namespace pika::lcos::detail
