@@ -16,7 +16,7 @@
 #include <pika/hardware/timestamp/cuda.hpp>
 #endif
 
-namespace pika { namespace util { namespace hardware {
+namespace pika::util::hardware {
 
     // clang-format off
     PIKA_HOST_DEVICE inline std::uint64_t timestamp()
@@ -24,29 +24,24 @@ namespace pika { namespace util { namespace hardware {
 #if defined(PIKA_HAVE_CUDA) && defined(PIKA_COMPUTE_DEVICE_CODE)
         return timestamp_cuda();
 #else
-        std::uint64_t r = 0;
-
+        std::uint32_t lo = 0, hi = 0;
         #if defined(PIKA_HAVE_RDTSCP)
             __asm__ __volatile__(
                 "rdtscp ;\n"
-                : "=A"(r)
+                : "=a"(lo), "=d"(hi)
                 :
-                : "%ecx");
+                : "rcx");
         #elif defined(PIKA_HAVE_RDTSC)
             __asm__ __volatile__(
-                "movl %%ebx, %%edi ;\n"
-                "xorl %%eax, %%eax ;\n"
                 "cpuid ;\n"
                 "rdtsc ;\n"
-                "movl %%edi, %%ebx ;\n"
-                : "=A"(r)
+                : "=a"(lo), "=d"(hi)
                 :
-                : "%edi", "%ecx");
+                : "rbx", "rcx");
         #endif
-
-        return r;
+        return ((static_cast<std::uint64_t>(hi)) << 32) | lo;
 #endif
     }
     // clang-format on
 
-}}}    // namespace pika::util::hardware
+}    // namespace pika::util::hardware
