@@ -4,12 +4,9 @@
 //  Distributed under the Boost Software License, Version 1.0. (See accompanying
 //  file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
-// pikainspect:nodeprecatedname:pika::util::result_of
-
 #pragma once
 
 #include <pika/functional/invoke_result.hpp>
-#include <pika/functional/traits/is_invocable.hpp>
 
 namespace pika {
     using pika::util::detail::invoke_result;
