@@ -38,12 +38,22 @@ extern char** environ;
 #endif
 
 ///////////////////////////////////////////////////////////////////////////////
-namespace pika { namespace util {
+namespace pika::util {
 
     ///////////////////////////////////////////////////////////////////////////////
     // example ini line: line # comment
     const char pattern_comment[] = "^([^#]*)(#.*)$";
     ///////////////////////////////////////////////////////////////////////////////
+    void section::set_root(section* r, bool recursive)
+    {
+        root_ = r;
+        if (recursive)
+        {
+            section_map::iterator send = sections_.end();
+            for (section_map::iterator si = sections_.begin(); si != send; ++si)
+                si->second.set_root(r, true);
+        }
+    }
 
     namespace detail {
         ///////////////////////////////////////////////////////////////////////////
@@ -986,4 +996,4 @@ namespace pika { namespace util {
         return value;
     }
 
-}}    // namespace pika::util
+}    // namespace pika::util
