@@ -10,7 +10,6 @@
 #include <pika/functional/detail/invoke.hpp>
 #include <pika/functional/invoke_fused.hpp>
 #include <pika/functional/invoke_result.hpp>
-#include <pika/functional/traits/is_invocable.hpp>
 #include <pika/pack_traversal/detail/container_category.hpp>
 #include <pika/pack_traversal/traits/pack_traversal_rebind_container.hpp>
 #include <pika/type_support/decay.hpp>
@@ -24,7 +23,7 @@
 #include <type_traits>
 #include <utility>
 
-namespace pika { namespace util { namespace detail {
+namespace pika::util::detail {
     /// Exposes useful facilities for dealing with 1:n mappings
     namespace spreading {
         /// A struct to mark a tuple to be unpacked into the parent context
@@ -301,7 +300,7 @@ namespace pika { namespace util { namespace detail {
     /// call to the mapper.
     template <typename Mapper, typename T>
     using is_effective_t =
-        pika::detail::is_invocable<typename Mapper::traversor_type, T>;
+        std::is_invocable<typename Mapper::traversor_type, T>;
 
     /// Deduces to a true type if any type leads to at least one effective
     /// call to the mapper.
@@ -933,4 +932,4 @@ namespace pika { namespace util { namespace detail {
             PIKA_FORWARD(Mapper, mapper));
         return helper.init_traverse(strategy, PIKA_FORWARD(T, pack)...);
     }
-}}}    // namespace pika::util::detail
+}    // namespace pika::util::detail
