@@ -13,9 +13,9 @@
 
 #include <string>
 
-namespace pika { namespace util {
+namespace pika::util {
     // return the full path of the current executable
     PIKA_EXPORT std::string get_executable_filename(
         char const* argv0 = nullptr);
     PIKA_EXPORT std::string get_executable_prefix(char const* argv0 = nullptr);
-}}    // namespace pika::util
+}    // namespace pika::util
