@@ -19,9 +19,9 @@
 #include <utility>
 #include <vector>
 
-namespace pika { namespace resource { namespace detail {
+namespace pika::resource::detail {
     PIKA_EXPORT partitioner& create_partitioner(
         resource::partitioner_mode rpmode, pika::util::section rtcfg,
         pika::detail::affinity_data affinity_data);
 
-}}}    // namespace pika::resource::detail
+}    // namespace pika::resource::detail
