@@ -17,7 +17,7 @@
 #include <utility>
 #include <vector>
 
-namespace pika { namespace resource {
+namespace pika::resource {
     ///////////////////////////////////////////////////////////////////////////
     std::vector<pu> pu::pus_sharing_core()
     {
@@ -138,6 +138,12 @@ namespace pika { namespace resource {
     }    // namespace detail
 
     ///////////////////////////////////////////////////////////////////////////
+    partitioner::partitioner(resource::partitioner_mode rpmode,
+        pika::util::section rtcfg, pika::detail::affinity_data affinity_data)
+      : partitioner_(detail::create_partitioner(rpmode, rtcfg, affinity_data))
+    {
+    }
+
     void partitioner::create_thread_pool(std::string const& name,
         scheduling_policy sched /*= scheduling_policy::unspecified*/,
         pika::threads::scheduler_mode mode)
@@ -218,4 +224,15 @@ namespace pika { namespace resource {
     {
         partitioner_.configure_pools();
     }
-}}    // namespace pika::resource
+
+    namespace detail {
+
+        ::pika::resource::partitioner make_partitioner(
+            resource::partitioner_mode rpmode, pika::util::section rtcfg,
+            pika::detail::affinity_data affinity_data)
+        {
+            return ::pika::resource::partitioner(rpmode, rtcfg, affinity_data);
+        }
+
+    }    // namespace detail
+}    // namespace pika::resource
