@@ -1,21 +1,14 @@
-__version__ = '0.11.2'
+__version__ = '0.12.0'
 
 import logging
-try:
-    # not available in python 2.6
-    from logging import NullHandler
-except ImportError:
-
-    class NullHandler(logging.Handler):
-
-        def emit(self, record):
-            pass
+from logging import NullHandler
 
 # Add NullHandler to prevent logging warnings
 logging.getLogger(__name__).addHandler(NullHandler())
 
 from pika.connection import ConnectionParameters
 from pika.connection import URLParameters
+from pika.connection import SSLOptions
 from pika.credentials import PlainCredentials
 from pika.spec import BasicProperties
 
@@ -24,4 +17,3 @@ from pika.adapters import BlockingConnection
 from pika.adapters import SelectConnection
 from pika.adapters import TornadoConnection
 from pika.adapters import TwistedConnection
-from pika.adapters import LibevConnection
