@@ -13,10 +13,10 @@ TwistedChannel class for details.
 
 """
 import functools
-import time
 from twisted.internet import defer, error, reactor
 from twisted.python import log
 
+from pika import connection
 from pika import exceptions
 from pika.adapters import base_connection
 
@@ -27,6 +27,7 @@ class ClosableDeferredQueue(defer.DeferredQueue):
     Exception instance all pending Deferreds are errbacked and further attempts
     to call get() or put() return a Failure wrapping that exception.
     """
+
     def __init__(self, size=None, backlog=None):
         self.closed = None
         super(ClosableDeferredQueue, self).__init__(size, backlog)
@@ -51,7 +52,7 @@ class ClosableDeferredQueue(defer.DeferredQueue):
 class TwistedChannel(object):
     """A wrapper wround Pika's Channel.
 
-    Channel methods that are normally take a callback argument are wrapped to
+    Channel methods that normally take a callback argument are wrapped to
     return a Deferred that fires with whatever would be passed to the callback.
     If the channel gets closed, all pending Deferreds are errbacked with a
     ChannelClosed exception. The returned Deferreds fire with whatever
@@ -61,10 +62,9 @@ class TwistedChannel(object):
     details.
     """
 
-    WRAPPED_METHODS = ('exchange_declare', 'exchange_delete',
-                       'queue_declare', 'queue_bind', 'queue_purge',
-                       'queue_unbind', 'basic_qos', 'basic_get',
-                       'basic_recover', 'tx_select', 'tx_commit',
+    WRAPPED_METHODS = ('exchange_declare', 'exchange_delete', 'queue_declare',
+                       'queue_bind', 'queue_purge', 'queue_unbind', 'basic_qos',
+                       'basic_get', 'basic_recover', 'tx_select', 'tx_commit',
                        'tx_rollback', 'flow', 'basic_cancel')
 
     def __init__(self, channel):
@@ -106,6 +106,9 @@ class TwistedChannel(object):
 
         try:
             consumer_tag = self.__channel.basic_consume(*args, **kwargs)
+        # TODO this except without types would suppress system-exiting
+        # exceptions, such as SystemExit and KeyboardInterrupt. It should be at
+        # least `except Exception` and preferably more specific.
         except:
             return defer.fail()
 
@@ -148,10 +151,25 @@ class TwistedChannel(object):
             d = defer.Deferred()
             self.__calls.add(d)
             d.addCallback(self.__clear_call, d)
-            kwargs['callback'] = d.callback
+
+            def single_argument(*args):
+                """
+                Make sure that the deferred is called with a single argument.
+                In case the original callback fires with more than one, convert
+                to a tuple.
+                """
+                if len(args) > 1:
+                    d.callback(tuple(args))
+                else:
+                    d.callback(*args)
+
+            kwargs['callback'] = single_argument
 
             try:
                 method(*args, **kwargs)
+            # TODO this except without types would suppress system-exiting
+            # exceptions, such as SystemExit and KeyboardInterrupt. It should be
+            # at least `except Exception` and preferably more specific.
             except:
                 return defer.fail()
             return d
@@ -180,6 +198,7 @@ class IOLoopReactorAdapter(object):
     Accepts a TwistedConnection object and a Twisted reactor object.
 
     """
+
     def __init__(self, connection, reactor):
         self.connection = connection
         self.reactor = reactor
@@ -206,6 +225,28 @@ class IOLoopReactorAdapter(object):
         """
         call.cancel()
 
+    def add_callback_threadsafe(self, callback):
+        """Requests a call to the given function as soon as possible in the
+        context of this IOLoop's thread.
+
+        NOTE: This is the only thread-safe method offered by the IOLoop adapter.
+         All other manipulations of the IOLoop adapter and its parent connection
+         must be performed from the connection's thread.
+
+        For example, a thread may request a call to the
+        `channel.basic_ack` method of a connection that is running in a
+        different thread via
+
+        ```
+        connection.add_callback_threadsafe(
+            functools.partial(channel.basic_ack, delivery_tag=...))
+        ```
+
+        :param method callback: The callback method; must be callable.
+
+        """
+        self.reactor.callFromThread(callback)
+
     def stop(self):
         # Guard against stopping the reactor multiple times
         if not self.started:
@@ -258,38 +299,35 @@ class TwistedConnection(base_connection.BaseConnection):
     IReadWriteDescriptor interface.
 
     """
-    def __init__(self, parameters=None,
+
+    def __init__(self,
+                 parameters=None,
                  on_open_callback=None,
+                 on_open_error_callback=None,
+                 on_close_callback=None,
                  stop_ioloop_on_close=False):
-        super(TwistedConnection, self).__init__(parameters, on_open_callback,
-                                                stop_ioloop_on_close)
+        super(TwistedConnection, self).__init__(
+            parameters=parameters,
+            on_open_callback=on_open_callback,
+            on_open_error_callback=on_open_error_callback,
+            on_close_callback=on_close_callback,
+            ioloop=IOLoopReactorAdapter(self, reactor),
+            stop_ioloop_on_close=stop_ioloop_on_close)
 
     def _adapter_connect(self):
         """Connect to the RabbitMQ broker"""
         # Connect (blockignly!) to the server
-        super(TwistedConnection, self)._adapter_connect()
-
-        # Create an I/O loop by adapting the Twisted reactor
-        self.ioloop = IOLoopReactorAdapter(self, reactor)
-
-        # Set the I/O events we're waiting for (see IOLoopReactorAdapter
-        # docstrings for why it's OK to pass None as the file descriptor)
-        self.ioloop.update_handler(None, self.event_state)
-
-        # Let everyone know we're connected
-        self._on_connected()
+        error = super(TwistedConnection, self)._adapter_connect()
+        if not error:
+            # Set the I/O events we're waiting for (see IOLoopReactorAdapter
+            # docstrings for why it's OK to pass None as the file descriptor)
+            self.ioloop.update_handler(None, self.event_state)
+        return error
 
     def _adapter_disconnect(self):
         """Called when the adapter should disconnect"""
         self.ioloop.remove_handler(None)
-        self.socket.close()
-
-    def _handle_disconnect(self):
-        """Do not stop the reactor, this would cause the entire process to exit,
-        just fire the disconnect callbacks
-
-        """
-        self._on_connection_closed(None, True)
+        self._cleanup_socket()
 
     def _on_connected(self):
         """Call superclass and then update the event state to flush the outgoing
@@ -323,7 +361,8 @@ class TwistedConnection(base_connection.BaseConnection):
         if not reason.check(error.ConnectionDone):
             log.err(reason)
 
-        self._handle_disconnect()
+        self._on_terminate(connection.InternalCloseReasons.SOCKET_ERROR,
+                           str(reason))
 
     def doRead(self):
         self._handle_read()
@@ -349,34 +388,39 @@ class TwistedProtocolConnection(base_connection.BaseConnection):
     because, yet again, it's Twisted who manages the connection.
 
     """
-    def __init__(self, parameters):
+
+    def __init__(self, parameters=None, on_close_callback=None):
         self.ready = defer.Deferred()
-        super(TwistedProtocolConnection, self).__init__(parameters,
-                                                        self.connectionReady)
-        self.ioloop = IOLoopReactorAdapter(self, reactor)
+        super(TwistedProtocolConnection, self).__init__(
+            parameters=parameters,
+            on_open_callback=self.connectionReady,
+            on_open_error_callback=self.connectionFailed,
+            on_close_callback=on_close_callback,
+            ioloop=IOLoopReactorAdapter(self, reactor),
+            stop_ioloop_on_close=False)
+
+    def connect(self):
+        # The connection is open asynchronously by Twisted, so skip the whole
+        # connect() part, except for setting the connection state
+        self._set_connection_state(self.CONNECTION_INIT)
 
     def _adapter_connect(self):
-        # We get connected by Twisted, as is normal for protocols
-        pass
+        # Should never be called, as we override connect() and leave the
+        # building of a TCP connection to Twisted, but implement anyway to keep
+        # the interface
+        return False
 
     def _adapter_disconnect(self):
         # Disconnect from the server
         self.transport.loseConnection()
 
-    def _send_frame(self, frame_value):
-        """Send data the Twisted way, by writing to the transport. No need for
-        buffering, Twisted handles that by itself.
-
-        :param frame_value: The frame to write
-        :type frame_value:  pika.frame.Frame|pika.frame.ProtocolHeader
-
+    def _flush_outbound(self):
+        """Override BaseConnection._flush_outbound to send all bufferred data
+        the Twisted way, by writing to the transport. No need for buffering,
+        Twisted handles that for us.
         """
-        if self.is_closed:
-            raise exceptions.ConnectionClosed
-        marshaled_frame = frame_value.marshal()
-        self.bytes_sent += len(marshaled_frame)
-        self.frames_sent += 1
-        self.transport.write(marshaled_frame)
+        while self.outbound_buffer:
+            self.transport.write(self.outbound_buffer.popleft())
 
     def channel(self, channel_number=None):
         """Create a new channel with the next available channel number or pass
@@ -421,3 +465,10 @@ class TwistedProtocolConnection(base_connection.BaseConnection):
         d, self.ready = self.ready, None
         if d:
             d.callback(res)
+
+    def connectionFailed(self, connection_unused, error_message=None):
+        d, self.ready = self.ready, None
+        if d:
+            attempts = self.params.connection_attempts
+            exc = exceptions.AMQPConnectionError(attempts)
+            d.errback(exc)
